
XEP-0410: MUC Self-Ping (Schrödinger's Chat)
============================================

.. module:: slixmpp.plugins.xep_0410

.. autoclass:: XEP_0410
    :members:
    :exclude-members: session_bind, plugin_init, plugin_end, _update_ping_results, _handle_condition, _on_muc_activity


.. autoclass:: PingStatus
   :members:
